pub struct Signature<C: EcdsaCurve> { /* private fields */ }Expand description
ECDSA signature (fixed-size, a.k.a. IEEE P1363). Generic over elliptic curve types.
Serialized as fixed-sized big endian scalar values with no added framing:
r: field element size for the given curve, big-endians: field element size for the given curve, big-endian
Both r and s MUST be non-zero.
For example, in a curve with a 256-bit modulus like NIST P-256 or secp256k1, r and s are
both 32-bytes and serialized as big endian, resulting in a signature with a total of 64-bytes.
ASN.1 DER-encoded signatures also supported via the Signature::from_der and
Signature::to_der methods.
serde support
When the serde feature of this crate is enabled, it provides support for serializing and
deserializing ECDSA signatures using the Serialize and Deserialize traits.
The serialization uses a hexadecimal encoding when used with “human readable” text formats, and a binary encoding otherwise.
Implementations
Sourceimpl<C> Signature<C>where
C: EcdsaCurve,
impl<C> Signature<C>where
C: EcdsaCurve,
Sourcepub fn from_bytes(bytes: &SignatureBytes<C>) -> Result<Self>
pub fn from_bytes(bytes: &SignatureBytes<C>) -> Result<Self>
Parse a signature from fixed-width bytes, i.e. 2 * the size of FieldBytes for a
particular curve.
Errors
If the r and/or s component of the signature is out-of-range when interpreted as a big
endian integer.
Sourcepub fn from_slice(slice: &[u8]) -> Result<Self>
pub fn from_slice(slice: &[u8]) -> Result<Self>
Parse a signature from a byte slice.
Errors
Returns Error in the event the signature is not the expected size, i.e. 2 * the size of
FieldBytes for a particular curve.
Sourcepub fn from_scalars(
r: impl Into<FieldBytes<C>>,
s: impl Into<FieldBytes<C>>,
) -> Result<Self>
pub fn from_scalars( r: impl Into<FieldBytes<C>>, s: impl Into<FieldBytes<C>>, ) -> Result<Self>
Sourcepub fn split_bytes(&self) -> (FieldBytes<C>, FieldBytes<C>)
pub fn split_bytes(&self) -> (FieldBytes<C>, FieldBytes<C>)
Split the signature into its r and s components, represented as bytes.
Sourcepub fn to_bytes(&self) -> SignatureBytes<C>
pub fn to_bytes(&self) -> SignatureBytes<C>
Serialize this signature as bytes.
Sourceimpl<C> Signature<C>where
C: EcdsaCurve + CurveArithmetic,
impl<C> Signature<C>where
C: EcdsaCurve + CurveArithmetic,
Sourcepub fn r(&self) -> NonZeroScalar<C>
Available on crate feature algorithm only.
pub fn r(&self) -> NonZeroScalar<C>
algorithm only.Get the r component of this signature
Sourcepub fn s(&self) -> NonZeroScalar<C>
Available on crate feature algorithm only.
pub fn s(&self) -> NonZeroScalar<C>
algorithm only.Get the s component of this signature
Sourcepub fn split_scalars(&self) -> (NonZeroScalar<C>, NonZeroScalar<C>)
Available on crate feature algorithm only.
pub fn split_scalars(&self) -> (NonZeroScalar<C>, NonZeroScalar<C>)
algorithm only.Split the signature into its r and s scalars.
Sourcepub fn normalize_s(&self) -> Self
Available on crate feature algorithm only.
pub fn normalize_s(&self) -> Self
algorithm only.Normalize signature into “low S” form described in BIP 0062: Dealing with Malleability.