SignatureWithOid

Struct SignatureWithOid 

pub struct SignatureWithOid<C: EcdsaCurve> { /* private fields */ }
An extended Signature type which is parameterized by an ObjectIdentifier which identifies the ECDSA variant used by a particular signature.

Valid ObjectIdentifiers are defined in RFC5758  3.2:

Implementations

Source

impl<C> SignatureWithOid<C>
where C: EcdsaCurve,

pub fn new(signature: Signature<C>, oid: ObjectIdentifier) -> Result<Self>

Create a new signature with an explicitly provided OID.

OID must begin with 1.2.840.10045.4, the RFC5758 OID prefix for ECDSA variants.

Errors

Returns Error if oid does not start with 1.2.840.10045.4.

pub fn new_with_digest<D>(signature: Signature<C>) -> Result<Self>
where D: AssociatedOid + Digest,

Create a new signature, determining the OID from the given digest.

Supports SHA-2 family digests as enumerated in RFC5758  3.2, i.e. SHA-224, SHA-256, SHA-384, or SHA-512.

Errors

Returns Error if the [AssociatedOid] for D is not one from the SHA2 family.

pub fn from_bytes_with_digest<D>(bytes: &SignatureBytes<C>) -> Result<Self>
where D: AssociatedOid + Digest,

Parse a signature from fixed-with bytes.

Errors

Returns Error if Signature fails to parse, or if D is not a valid digest. See SignatureWithOid::new_with_digest documentation.

pub fn from_slice_with_digest<D>(slice: &[u8]) -> Result<Self>
where D: AssociatedOid + Digest,

Parse a signature from a byte slice.

Errors

Returns Error if Signature fails to parse, or if D is not a valid digest. See SignatureWithOid::new_with_digest documentation.

pub fn from_der_with_digest<D>(der_bytes: &[u8]) -> Result<Self>
where D: AssociatedOid + Digest, MaxSize<C>: ArraySize, <FieldBytesSize<C> as Add>::Output: Add<MaxOverhead> + ArraySize,

Parse a signature from ASN.1 DER and associate the given digest’s OID with it.

Errors

Returns Error if input failed to parse as an ASN.1 DER-encoded ECDSA signature, or if D is not a valid digest.

pub fn from_der_with_oid( der_bytes: &[u8], oid: ObjectIdentifier, ) -> Result<Self>
where MaxSize<C>: ArraySize, <FieldBytesSize<C> as Add>::Output: Add<MaxOverhead> + ArraySize,

Parse a signature from ASN.1 DER and associate the given OID with it.

Errors

Returns Error if input failed to parse as an ASN.1 DER-encoded ECDSA signature, or if D is not a valid digest.

pub fn signature(&self) -> &Signature<C>

Get the fixed-width ECDSA signature.

pub fn oid(&self) -> ObjectIdentifier

Get the ECDSA OID for this signature.

pub fn to_bytes(&self) -> SignatureBytes<C>

Serialize this signature as fixed-width bytes.

pub fn to_der(&self) -> Signature<C>
where MaxSize<C>: ArraySize, <FieldBytesSize<C> as Add>::Output: Add<MaxOverhead> + ArraySize,

Serialize this signature as ASN.1 DER.

Note that this includes only the r and s signature components, and not the OID.

See der::Signature documentation for more information.